@@ -75,7 +75,7 @@ import           Data.Word ( Word8 )
 import qualified Graphics.DemoCat.CairoSDL as HC ( createSurfacePair )
 
 import qualified Graphics.DemoCat.Render.Render as HRR ( renderFrames )
-import           Graphics.DemoCat.Util ( checkError )
+import           Graphics.DemoCat.SDLUtil ( checkSDLError )
 
 numRepeats = 5
 takeFrames = 50
@@ -85,16 +85,16 @@ bgOnly = False
 main :: IO ()
 main = do
 
-    checkError "begin"
+    checkSDLError "begin"
     initializeAll
-    checkError "initializeAll"
+    checkSDLError "initializeAll"
     window <- createWindow "wuddup" $
         defaultWindow { windowInitialSize = V2 480 800 }
-    checkError "createWindow"
+    checkSDLError "createWindow"
     renderer <- createRenderer window (-1) $
         defaultRenderer { rendererTargetTexture = False
                         , rendererType = AcceleratedRenderer }
-    checkError "createRenderer"
+    checkSDLError "createRenderer"
     (sdlSurf, cairoSurf) <- HC.createSurfacePair bgOnly
     framesRight <- HRR.renderFrames False
     framesLeft <- HRR.renderFrames True
